@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.14";
+our $VERSION = "0.15";
 
 use Exporter qw/import/;
 our @EXPORT_OK = qw/
@@ -35,7 +35,7 @@ Hash::Util::Pick - The non-destructive utilities for picking hash
         baz => 2,
     };
 
-    my $dest = pick $hash => qw/foo bar/;
+    my $dest = pick $src => qw/foo bar/;
     # => { foo => 0, bar => 1 }
 
 =head1 DESCRIPTION
